==> tellico_2.3.9+dfsg.1.orig.tar.xz: tellico-2.3.9+dfsg.1/src/gui/previewdialog.h <==
/***************************************************************************
    Copyright (C) 2006-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_GUI_PREVIEWDIALOG_H
#define TELLICO_GUI_PREVIEWDIALOG_H

#include <kdialog.h>

#include "../datavectors.h"

class KTempDir;

namespace Tellico {
  class EntryView;
  class StyleOptions;

  namespace GUI {

class PreviewDialog : public KDialog {
Q_OBJECT

public:
  PreviewDialog(QWidget* parent);
  ~PreviewDialog();

  void setXSLTFile(const QString& file);
  void setXSLTOptions(int collectionType, StyleOptions options);
  void showEntry(Data::EntryPtr entry);

private:
  KTempDir* m_tempDir;
  EntryView* m_view;
};

  }
}
#endif

==> tellico_4.2.orig.tar.xz: tellico-4.2/src/gui/previewdialog.h <==
/***************************************************************************
    Copyright (C) 2006-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_GUI_PREVIEWDIALOG_H
#define TELLICO_GUI_PREVIEWDIALOG_H

#include <QDialog>

#include "../datavectors.h"

class QTemporaryDir;

namespace Tellico {
  class EntryView;
  class StyleOptions;

  namespace GUI {

class PreviewDialog : public QDialog {
Q_OBJECT

public:
  PreviewDialog(QWidget* parent);
  ~PreviewDialog();

  void setXSLTFile(const QString& file);
  void setXSLTOptions(int collectionType, StyleOptions options);
  void showEntry(Data::EntryPtr entry);

private:
  QTemporaryDir* m_tempDir;
  EntryView* m_view;
};

  }
}
#endif
